==> jc-1.4.0.tar.gz: soot/ScenePack.c <==
// public class soot.ScenePack

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class be56ff673eefd9d2 java_util_Iterator
// @dep_class 5eaf00c8573648 soot_HasPhaseOptions
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack
// @dep_class 159027a04d2ef42e soot_Transform
// @dep_class 137960643ebf2744 soot_util_HashChain

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_HashMap
// @dep_header java_util_Iterator
// @dep_header soot_HasPhaseOptions
// @dep_header soot_ScenePack
// @dep_header soot_Transform
// @dep_header soot_util_HashChain

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/HashMap.h"
#include "java/util/Iterator.h"
#include "soot/HasPhaseOptions.h"
#include "soot/ScenePack.h"
#include "soot/Transform.h"
#include "soot/util/HashChain.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_soot_ScenePack$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_soot_ScenePack$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_ScenePack$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_ScenePack$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_soot_ScenePack$type,
	.param_types=		&_jc_soot_ScenePack$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_ScenePack$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_ScenePack$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_ScenePack$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_ScenePack, _init$c31b894660454d13);

void
_jc_soot_ScenePack$method$_init$c31b894660454d13(_jc_env *const env, _jc_soot_ScenePack$object *this, _jc_java_lang_String$object *param0)
{
	_jc_object *n0;
	struct _jc_soot_ScenePack$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_soot_util_HashChain$object *r2;
	struct _jc_java_util_HashMap$object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = _JC_NEW(env, soot_util_HashChain);
	r3 = _JC_NEW(env, java_util_HashMap);
	_JC_INVOKE_NONVIRTUAL(env, java_util_HashMap, _init$7cb044ce4fb0ada8, 0, r3, 11, _JC_FCONST(0x3f, 0x40, 0x0, 0x0));
	_JC_REF_FIELD(env, r2, soot_util_HashChain, map) = r3;
	_JC_PRIM_FIELD(env, r2, soot_util_HashChain, stateCount) = _JC_JLONG(0);
	n0 = _JC_NULL;
	_JC_REF_FIELD(env, r2, soot_util_HashChain, lastItem) = n0;
	_JC_REF_FIELD(env, r2, soot_util_HashChain, firstItem) = n0;
	_JC_REF_FIELD(env, r0, soot_Pack, opts) = r2;
	_JC_REF_FIELD(env, r0, soot_Pack, name) = r1;
	_JC_LINE_NUMBER(38);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// protected void internalApply()
//

static _jc_linenum _jc_soot_ScenePack$linenum_table$internalApply$e44bdfd255a61742[];

static const unsigned char _jc_soot_ScenePack$param_ptypes$internalApply$e44bdfd255a61742[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_ScenePack$method_info$internalApply$e44bdfd255a61742 = {
	.name=			"internalApply",
	.signature=		"()V",
	.class=			&_jc_soot_ScenePack$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_ScenePack$param_ptypes$internalApply$e44bdfd255a61742,
	.signature_hash=	_JC_JLONG(0xe44bdfd255a61742),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_ScenePack$vtable, soot_ScenePack.internalApply$e44bdfd255a61742) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_soot_ScenePack$linenum_table$internalApply$e44bdfd255a61742
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_ScenePack, internalApply$e44bdfd255a61742);

void
_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742(_jc_env *const env, _jc_soot_ScenePack$object *this)
{
	struct _jc_soot_ScenePack$object *r0;
	struct _jc_object *r1;
	struct _jc_soot_Transform$object *r2;
	struct _jc_java_lang_Object$object *r3;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(42);				// 0
	r1 = _JC_INVOKE_VIRTUAL(env, soot_Pack, iterator$3cc91493d50f531c, r0);

label0:
	z0 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean);
	if (z0 == 0)
		goto label1;
	_JC_LINE_NUMBER(43);				// 1
	r3 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *);
	r2 = _JC_CAST(env, &_jc_soot_Transform$type, r3);
	_JC_LINE_NUMBER(44);				// 2
	_JC_INVOKE_VIRTUAL(env, soot_Transform, apply$419a858a98fff6e4, r2);
	_JC_PERIODIC_CHECK(env);
	goto label0;

label1:
	_JC_LINE_NUMBER(46);				// 3
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_ScenePack$methods[] = {
	&_jc_soot_ScenePack$method_info$_init$c31b894660454d13,
	&_jc_soot_ScenePack$method_info$internalApply$e44bdfd255a61742
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_ScenePack$imethod_hash_bucket_21[] = {
	&_jc_soot_Pack$method_info$getPhaseName$2887e3dd2a5edf95,
	_JC_NULL
};
static _jc_method *_jc_soot_ScenePack$imethod_hash_bucket_55[] = {
	&_jc_soot_Pack$method_info$getDefaultOptions$2203c46727b257b7,
	_JC_NULL
};
static _jc_method *_jc_soot_ScenePack$imethod_hash_bucket_80[] = {
	&_jc_soot_Pack$method_info$getDeclaredOptions$2a659a8d8e2219d0,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_ScenePack$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[21]=	_jc_soot_ScenePack$imethod_hash_bucket_21,
	[55]=	_jc_soot_ScenePack$imethod_hash_bucket_55,
	[80]=	_jc_soot_ScenePack$imethod_hash_bucket_80
};

// Interface "quick" lookup hash table
static const void *_jc_soot_ScenePack$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[21]=	&_jc_soot_Pack$method$getPhaseName$2887e3dd2a5edf95,
	[55]=	&_jc_soot_Pack$method$getDefaultOptions$2203c46727b257b7,
	[80]=	&_jc_soot_Pack$method$getDeclaredOptions$2a659a8d8e2219d0
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_26[] = {
	&_jc_soot_Pack$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_72[] = {
	&_jc_soot_HasPhaseOptions$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_89[] = {
	&_jc_soot_ScenePack$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_ScenePack$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[26]=	_jc_soot_ScenePack$instanceof_hash_bucket_26,
	[72]=	_jc_soot_ScenePack$instanceof_hash_bucket_72,
	[89]=	_jc_soot_ScenePack$instanceof_hash_bucket_89,
	[113]=	_jc_soot_ScenePack$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_ScenePack$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/AbstractCollection",	_JC_JLONG(0x8ea716c64b77f8eb) },
	{ "java/util/HashMap",	_JC_JLONG(0xd7cd853200c3e71f) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
	{ "soot/HasPhaseOptions",	_JC_JLONG(0x5eaf00c8573648) },
	{ "soot/Pack",	_JC_JLONG(0x65aca5ceab69719a) },
	{ "soot/Transform",	_JC_JLONG(0x159027a04d2ef42e) },
	{ "soot/util/HashChain",	_JC_JLONG(0x137960643ebf2744) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_ScenePack$vtype _jc_soot_ScenePack$type = {
    .type= {
	.name=			"soot/ScenePack",
	.superclass=		&_jc_soot_Pack$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_ScenePack$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_ScenePack$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		24,
		.hash=			_JC_JLONG(0x4847c782d4c3e1d9),
		.source_file=		"ScenePack.java",
		.instance_size=		sizeof(_jc_soot_ScenePack$refs) + sizeof(_jc_soot_ScenePack$object),
		.num_virtual_refs=	2,
		.num_methods=		sizeof(_jc_soot_ScenePack$methods) / sizeof(*_jc_soot_ScenePack$methods),
		.methods=		_jc_soot_ScenePack$methods,
		.instanceof_hash_table=	_jc_soot_ScenePack$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_ScenePack$class_depends) / sizeof(*_jc_soot_ScenePack$class_depends),
		.class_depends=		_jc_soot_ScenePack$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_Pack= {
	    .add$2ce7b6f7bdda3730=
		&_jc_soot_Pack$method$add$2ce7b6f7bdda3730,
	    .apply$419a858a98fff6e4=
		&_jc_soot_Pack$method$apply$419a858a98fff6e4,
	    .apply$e5921dbd1be81b5f=
		&_jc_soot_Pack$method$apply$e5921dbd1be81b5f,
	    .get$0f851e86b93ac35c=
		&_jc_soot_Pack$method$get$0f851e86b93ac35c,
	    .getDeclaredOptions$2a659a8d8e2219d0=
		&_jc_soot_Pack$method$getDeclaredOptions$2a659a8d8e2219d0,
	    .getDefaultOptions$2203c46727b257b7=
		&_jc_soot_Pack$method$getDefaultOptions$2203c46727b257b7,
	    .getPhaseName$2887e3dd2a5edf95=
		&_jc_soot_Pack$method$getPhaseName$2887e3dd2a5edf95,
	    .insertAfter$b9234295296f9b83=
		&_jc_soot_Pack$method$insertAfter$b9234295296f9b83,
	    .insertBefore$06bf7c7db00d0f75=
		&_jc_soot_Pack$method$insertBefore$06bf7c7db00d0f75,
	    .internalApply$e44bdfd255a61742=		// overridden
		&_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742,
	    .internalApply$8c8b8fe09b775776=
		&_jc_soot_Pack$method$internalApply$8c8b8fe09b775776,
	    .iterator$3cc91493d50f531c=
		&_jc_soot_Pack$method$iterator$3cc91493d50f531c,
	},
	.soot_ScenePack= {
	    .internalApply$e44bdfd255a61742=
		&_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/ScenePack.c <==
// public class soot.ScenePack

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class be56ff673eefd9d2 java_util_Iterator
// @dep_class 5eaf00c8573648 soot_HasPhaseOptions
// @dep_class 65aca5ceab69719a soot_Pack
// @dep_class 4847c782d4c3e1d9 soot_ScenePack
// @dep_class 159027a04d2ef42e soot_Transform
// @dep_class 137960643ebf2744 soot_util_HashChain

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_HashMap
// @dep_header java_util_Iterator
// @dep_header soot_HasPhaseOptions
// @dep_header soot_ScenePack
// @dep_header soot_Transform
// @dep_header soot_util_HashChain

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/HashMap.h"
#include "java/util/Iterator.h"
#include "soot/HasPhaseOptions.h"
#include "soot/ScenePack.h"
#include "soot/Transform.h"
#include "soot/util/HashChain.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String)
//

static _jc_linenum _jc_soot_ScenePack$linenum_table$_init$c31b894660454d13[];

static const unsigned char _jc_soot_ScenePack$param_ptypes$_init$c31b894660454d13[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_ScenePack$param_types$_init$c31b894660454d13[] = {
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_ScenePack$method_info$_init$c31b894660454d13 = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;)V",
	.class=			&_jc_soot_ScenePack$type,
	.param_types=		&_jc_soot_ScenePack$param_types$_init$c31b894660454d13,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_ScenePack$param_ptypes$_init$c31b894660454d13,
	.signature_hash=	_JC_JLONG(0xc31b894660454d13),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_ScenePack$method$_init$c31b894660454d13,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_soot_ScenePack$linenum_table$_init$c31b894660454d13
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_ScenePack, _init$c31b894660454d13);

void _JC_JCNI_ATTR
_jc_soot_ScenePack$method$_init$c31b894660454d13(_jc_env *const env, _jc_soot_ScenePack$object *this, _jc_java_lang_String$object *param0)
{
	_jc_object *n0;
	struct _jc_soot_ScenePack$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_soot_util_HashChain$object *r2;
	struct _jc_java_util_HashMap$object *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = param0;
	r2 = _JC_NEW(env, soot_util_HashChain);
	r3 = _JC_NEW(env, java_util_HashMap);
	_JC_INVOKE_NONVIRTUAL(env, java_util_HashMap, _init$7cb044ce4fb0ada8, 0, r3, 11, _JC_FCONST(0x3f, 0x40, 0x0, 0x0));
	_JC_REF_FIELD(env, r2, soot_util_HashChain, map) = r3;
	_JC_PRIM_FIELD(env, r2, soot_util_HashChain, stateCount) = _JC_JLONG(0);
	n0 = _JC_NULL;
	_JC_REF_FIELD(env, r2, soot_util_HashChain, lastItem) = n0;
	_JC_REF_FIELD(env, r2, soot_util_HashChain, firstItem) = n0;
	_JC_REF_FIELD(env, r0, soot_Pack, opts) = r2;
	_JC_REF_FIELD(env, r0, soot_Pack, name) = r1;
	_JC_LINE_NUMBER(38);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// protected void internalApply()
//

static _jc_linenum _jc_soot_ScenePack$linenum_table$internalApply$e44bdfd255a61742[];

static const unsigned char _jc_soot_ScenePack$param_ptypes$internalApply$e44bdfd255a61742[] = { 
_JC_TYPE_VOID };

_jc_method _jc_soot_ScenePack$method_info$internalApply$e44bdfd255a61742 = {
	.name=			"internalApply",
	.signature=		"()V",
	.class=			&_jc_soot_ScenePack$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_ScenePack$param_ptypes$internalApply$e44bdfd255a61742,
	.signature_hash=	_JC_JLONG(0xe44bdfd255a61742),
	.access_flags=		_JC_ACC_PROTECTED,
	.function=		&_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_ScenePack$vtable, soot_ScenePack.internalApply$e44bdfd255a61742) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_soot_ScenePack$linenum_table$internalApply$e44bdfd255a61742
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_ScenePack, internalApply$e44bdfd255a61742);

void _JC_JCNI_ATTR
_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742(_jc_env *const env, _jc_soot_ScenePack$object *this)
{
	struct _jc_soot_ScenePack$object *r0;
	struct _jc_object *r1;
	struct _jc_soot_Transform$object *r2;
	struct _jc_java_lang_Object$object *r3;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(42);				// 0
	r1 = _JC_INVOKE_VIRTUAL(env, soot_Pack, iterator$3cc91493d50f531c, r0);

label0:
	z0 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean, (_jc_env *, struct _jc_object *));
	if (z0 == 0)
		goto label1;
	_JC_LINE_NUMBER(43);				// 1
	r3 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *, (_jc_env *, struct _jc_object *));
	r2 = _JC_CAST(env, &_jc_soot_Transform$type, r3);
	_JC_LINE_NUMBER(44);				// 2
	_JC_INVOKE_VIRTUAL(env, soot_Transform, apply$419a858a98fff6e4, r2);
	_JC_PERIODIC_CHECK(env);
	goto label0;

label1:
	_JC_LINE_NUMBER(46);				// 3
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_ScenePack$methods[] = {
	&_jc_soot_ScenePack$method_info$_init$c31b894660454d13,
	&_jc_soot_ScenePack$method_info$internalApply$e44bdfd255a61742
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_soot_ScenePack$imethod_hash_bucket_21[] = {
	&_jc_soot_Pack$method_info$getPhaseName$2887e3dd2a5edf95,
	_JC_NULL
};
static _jc_method *_jc_soot_ScenePack$imethod_hash_bucket_55[] = {
	&_jc_soot_Pack$method_info$getDefaultOptions$2203c46727b257b7,
	_JC_NULL
};
static _jc_method *_jc_soot_ScenePack$imethod_hash_bucket_80[] = {
	&_jc_soot_Pack$method_info$getDeclaredOptions$2a659a8d8e2219d0,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_soot_ScenePack$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[21]=	_jc_soot_ScenePack$imethod_hash_bucket_21,
	[55]=	_jc_soot_ScenePack$imethod_hash_bucket_55,
	[80]=	_jc_soot_ScenePack$imethod_hash_bucket_80
};

// Interface "quick" lookup hash table
static const void *_jc_soot_ScenePack$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[21]=	&_jc_soot_Pack$method$getPhaseName$2887e3dd2a5edf95,
	[55]=	&_jc_soot_Pack$method$getDefaultOptions$2203c46727b257b7,
	[80]=	&_jc_soot_Pack$method$getDeclaredOptions$2a659a8d8e2219d0
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_26[] = {
	&_jc_soot_Pack$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_72[] = {
	&_jc_soot_HasPhaseOptions$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_89[] = {
	&_jc_soot_ScenePack$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_ScenePack$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_ScenePack$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[26]=	_jc_soot_ScenePack$instanceof_hash_bucket_26,
	[72]=	_jc_soot_ScenePack$instanceof_hash_bucket_72,
	[89]=	_jc_soot_ScenePack$instanceof_hash_bucket_89,
	[101]=	_jc_soot_ScenePack$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_ScenePack$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/AbstractCollection",	_JC_JLONG(0x8ea716c64b77f8eb) },
	{ "java/util/HashMap",	_JC_JLONG(0xd7cd853200c3e71f) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
	{ "soot/HasPhaseOptions",	_JC_JLONG(0x5eaf00c8573648) },
	{ "soot/Pack",	_JC_JLONG(0x65aca5ceab69719a) },
	{ "soot/Transform",	_JC_JLONG(0x159027a04d2ef42e) },
	{ "soot/util/HashChain",	_JC_JLONG(0x137960643ebf2744) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_ScenePack$vtype _jc_soot_ScenePack$type = {
    .type= {
	.name=			"soot/ScenePack",
	.superclass=		&_jc_soot_Pack$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_soot_ScenePack$imethod_hash_table,
	.imethod_quick_table=	_jc_soot_ScenePack$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		24,
		.hash=			_JC_JLONG(0x4847c782d4c3e1d9),
		.source_file=		"ScenePack.java",
		.instance_size=		sizeof(_jc_soot_ScenePack$refs) + sizeof(_jc_soot_ScenePack$object),
		.num_virtual_refs=	2,
		.num_methods=		sizeof(_jc_soot_ScenePack$methods) / sizeof(*_jc_soot_ScenePack$methods),
		.methods=		_jc_soot_ScenePack$methods,
		.instanceof_hash_table=	_jc_soot_ScenePack$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_ScenePack$class_depends) / sizeof(*_jc_soot_ScenePack$class_depends),
		.class_depends=		_jc_soot_ScenePack$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_Pack= {
	    .add$2ce7b6f7bdda3730=
		&_jc_soot_Pack$method$add$2ce7b6f7bdda3730,
	    .apply$419a858a98fff6e4=
		&_jc_soot_Pack$method$apply$419a858a98fff6e4,
	    .apply$e5921dbd1be81b5f=
		&_jc_soot_Pack$method$apply$e5921dbd1be81b5f,
	    .get$0f851e86b93ac35c=
		&_jc_soot_Pack$method$get$0f851e86b93ac35c,
	    .getDeclaredOptions$2a659a8d8e2219d0=
		&_jc_soot_Pack$method$getDeclaredOptions$2a659a8d8e2219d0,
	    .getDefaultOptions$2203c46727b257b7=
		&_jc_soot_Pack$method$getDefaultOptions$2203c46727b257b7,
	    .getPhaseName$2887e3dd2a5edf95=
		&_jc_soot_Pack$method$getPhaseName$2887e3dd2a5edf95,
	    .insertAfter$b9234295296f9b83=
		&_jc_soot_Pack$method$insertAfter$b9234295296f9b83,
	    .insertBefore$06bf7c7db00d0f75=
		&_jc_soot_Pack$method$insertBefore$06bf7c7db00d0f75,
	    .internalApply$e44bdfd255a61742=		// overridden
		&_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742,
	    .internalApply$8c8b8fe09b775776=
		&_jc_soot_Pack$method$internalApply$8c8b8fe09b775776,
	    .iterator$3cc91493d50f531c=
		&_jc_soot_Pack$method$iterator$3cc91493d50f531c,
	},
	.soot_ScenePack= {
	    .internalApply$e44bdfd255a61742=
		&_jc_soot_ScenePack$method$internalApply$e44bdfd255a61742,
	},
    }
};
